# NOT RUN {
# }
# NOT RUN {
# Set the current directory to the git repository concerned.
setwd("./Path/to/repository")
# Set the file-path
t_path <- "Path/to/file"
# Load the library and pass the parameters to the function
library(Rperform)
compare_branchm(test_path = t_path, branch1 = "helper", branch2 = "master")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab