## Not run:
# # Set the current directory to the parent directory of the concerned repositories.
# setwd("./Path/to/parent/directory")
#
# # Set the directory paths
# d_path1 <- "Path/to/first/directory"
# d_path2 <- "Path/to/second/directory"
#
# # Set the file-paths
# t_path1 <- "First/path/to/file"
# t_path2 <- "Second/path/to/file"
#
# # Load the library and pass the parameters to the function
# library(Rperform)
# compare_dirt(d_path1, t_path1, branch1 = "master",
# d_path2, t_path2, branch2 = "patch")
# ## End(Not run)
Run the code above in your browser using DataLab