# NOT RUN {
# }
# NOT RUN {
# Set the current directory to the git repository concerned.
setwd("./Path/to/repository")
# Set the file-path
t_path <- "Path/to/file"
# Load the library and pass the parameters to the function
library(Rperform)
time_branch(test_path = t_path, branch_name = "helper", num_commits = 10)
# }
Run the code above in your browser using DataLab